@@ -1,5 +1,4 @@
-import requests
-from datomizer.helpers.authentication import authentication_helper
+from datomizer.helpers.authentication.authentication_helper import *
 from datomizer.utils.general import ACCESS_TOKEN, REFRESH_TOKEN, AUTHORIZATION, BEARER_TOKEN, D_REALM
 
 
@@ -18,16 +17,16 @@ class Datomizer(object):
             password: your password
         Returns:
             Datomizer Authentication object"""
-        self.domain = authentication_helper.get_domain_by_username(username=username, env=env)
-        self.realm = authentication_helper.get_realm_by_domain(domain=self.domain)
-        token_response = authentication_helper.post_token(realm=self.realm, domain=self.domain,
-                                                          username=username, password=password)
+        self.domain = get_domain_by_username(username=username, env=env)
+        self.realm = get_realm_by_domain(domain=self.domain)
+        token_response = post_token(realm=self.realm, domain=self.domain,
+                                    username=username, password=password)
         self.config_token(token_response)
 
     def refresh_token_headers(self):
-        token_response = authentication_helper.post_refresh_token(realm=self.realm,
-                                                                  domain=self.domain,
-                                                                  token=self.refresh_token)
+        token_response = post_refresh_token(realm=self.realm,
+                                            domain=self.domain,
+                                            token=self.refresh_token)
         self.config_token(token_response)
 
     def config_token(self, token_response):
@@ -75,6 +74,12 @@ class Datomizer(object):
             print(response.content)
             raise Exception(not_valid_message)
 
-    def __del__(self):
-        authentication_helper.post_log_out(realm=self.realm, domain=self.domain,
-                                           token=self.access_token, refresh_token=self.refresh_token)
+    def close(self):
+        post_log_out(realm=self.realm, domain=self.domain,
+                     token=self.access_token, refresh_token=self.refresh_token)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
