@@ -30,3 +30,6 @@ class SchemaWrapper(object):
                 return column
 
         return columns[0]
+
+    def __str__(self):
+        return str(self.schema)
